=======
Credits
=======

Development Lead
----------------

* Lukas Gamper <gamperl@gmail.com>
* Joel Akeret <jakeret@phys.ethz.ch>


Contributors
------------

We would like to thank several people for helping to test this package before release. 

* Alexandre Refregier
* Adam Amara
* Claudio Bruderer
* Chihway Chang
* Sebastian Gaebel 
* Joerg Herbel 


Citations
---------

As you use **HOPE** for your exciting discoveries, please cite the paper that describes the package: 

`Akeret, J., Gamper, L., Amara, A. and Refregier, A., Astronomy and Computing (2015) <http://www.sciencedirect.com/science/article/pii/S2213133714000687>`_

Feedback
--------

If you have any suggestions or questions about **HOPE** feel free to email me
at hope@phys.ethz.ch.

If you encounter any errors or problems with **HOPE**, please let me know!